"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Editor = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const state_1 = require("@codemirror/state");
const view_1 = require("@codemirror/view");
const react_1 = require("react");
const extensions_1 = require("../extensions.cjs");
const store_1 = require("../store.cjs");
/** CodeMirror editor. */
function Editor(props) {
    const { editable = true, group: groupId = "default" } = props;
    const store = (0, store_1.useBoothStore)();
    const ref = (0, react_1.useRef)();
    (0, react_1.useEffect)(() => {
        // be idempotent
        const state = store.getState();
        if (state.groups[groupId]?.files.some((file) => file.filename === props.filename)) {
            return;
        }
        // create editor
        const view = new view_1.EditorView({
            state: state_1.EditorState.create({
                doc: props.content ?? "",
                extensions: [
                    extensions_1.recording.of([]),
                    extensions_1.shortcuts.of([]),
                    ...(editable ? [] : [view_1.EditorView.editable.of(false)]),
                    ...(props.extensions ?? []),
                ],
            }),
        });
        ref.current.replaceWith(view.dom);
        // insert into state
        store.setState((prev) => {
            const group = prev.groups[groupId] ?? {
                activeFile: props.filename,
                files: [],
            };
            return {
                activeGroup: prev.activeGroup || groupId,
                groups: {
                    ...prev.groups,
                    [groupId]: {
                        activeFile: group.activeFile,
                        files: [
                            ...group.files,
                            {
                                editable,
                                filename: props.filename,
                                view,
                            },
                        ],
                    },
                },
            };
        });
    }, []);
    return (0, jsx_runtime_1.jsx)("div", { ref: ref });
}
exports.Editor = Editor;
