import { jsx as _jsx } from "react/jsx-runtime";
import { EditorState } from "@codemirror/state";
import { EditorView } from "@codemirror/view";
import { useEffect, useRef } from "react";
import { recording, shortcuts } from "../extensions.mjs";
import { useBoothStore } from "../store.mjs";
/** CodeMirror editor. */
export function Editor(props) {
    const { editable = true, group: groupId = "default" } = props;
    const store = useBoothStore();
    const ref = useRef();
    useEffect(() => {
        // be idempotent
        const state = store.getState();
        if (state.groups[groupId]?.files.some((file) => file.filename === props.filename)) {
            return;
        }
        // create editor
        const view = new EditorView({
            state: EditorState.create({
                doc: props.content ?? "",
                extensions: [
                    recording.of([]),
                    shortcuts.of([]),
                    ...(editable ? [] : [EditorView.editable.of(false)]),
                    ...(props.extensions ?? []),
                ],
            }),
        });
        ref.current.replaceWith(view.dom);
        // insert into state
        store.setState((prev) => {
            const group = prev.groups[groupId] ?? {
                activeFile: props.filename,
                files: [],
            };
            return {
                activeGroup: prev.activeGroup || groupId,
                groups: {
                    ...prev.groups,
                    [groupId]: {
                        activeFile: group.activeFile,
                        files: [
                            ...group.files,
                            {
                                editable,
                                filename: props.filename,
                                view,
                            },
                        ],
                    },
                },
            };
        });
    }, []);
    return _jsx("div", { ref: ref });
}
