import { jsx as _jsx } from "react/jsx-runtime";
import { drawSelection, ViewPlugin } from "@codemirror/view";
import { cmReplay, cmReplayMultiple, fakeSelection, selectCmd, } from "@lqv/codemirror";
import { useME } from "@lqv/playback/react";
import { useCallback, useEffect, useMemo } from "react";
import { useBoothStore } from "../store.mjs";
import { Editor } from "./Editor.mjs";
/**
 * Editor to replay recorded coding.
 */
export function Replay(props) {
    const store = useBoothStore();
    const playback = useME();
    const { extensions = [], handle, replay, start = 0, ...attrs } = props;
    const __handle = useCallback((cmd, doc) => {
        if (cmd === "run") {
            // run command
            store.setState((state) => ({ run: state.run + 1 }));
        }
        else if (cmd === "clear") {
            // clear console
            store.setState(() => ({ messages: [] }));
        }
        // userspace handler
        if (props.handle) {
            props.handle(store, cmd, doc);
        }
    }, [handle]);
    const __extensions = useMemo(() => [
        ViewPlugin.define(fakeSelection(drawSelection())),
        ViewPlugin.define((view) => {
            if (replay) {
                if (replay instanceof Promise) {
                    replay.then((data) => cmReplay({
                        data,
                        handle: __handle,
                        playback,
                        start,
                        view,
                    }));
                }
                else {
                    cmReplay({
                        data: replay,
                        handle: __handle,
                        playback,
                        start,
                        view,
                    });
                }
            }
            return {};
        }),
        ...extensions,
    ], [extensions, replay, start]);
    return _jsx(Editor, { editable: false, extensions: __extensions, ...attrs });
}
/**
 * Replay coding to multiple editors.
 */
export function ReplayMultiple(props) {
    const playback = useME();
    const store = useBoothStore();
    const { start = 0 } = props;
    /* Handle callback */
    const handle = useCallback((cmd, docs) => {
        // file selection change
        if (cmd.startsWith(selectCmd)) {
            store.setState((state) => ({
                groups: {
                    ...state.groups,
                    [props.group]: {
                        ...state.groups[props.group],
                        activeFile: cmd.slice(selectCmd.length),
                    },
                },
            }));
        }
        else if (cmd === "run") {
            // run command
            store.setState((state) => ({ run: state.run + 1 }));
        }
        else if (cmd === "clear") {
            // clear console
            store.setState(() => ({ messages: [] }));
        }
        // userspace handler
        if (props.handle) {
            props.handle(store, cmd, docs);
        }
    }, [props.handle]);
    useEffect(() => {
        const state = store.getState();
        const views = {};
        for (const file of state.groups[props.group].files) {
            views[file.filename] = file.view;
        }
        if (props.replay instanceof Promise) {
            props.replay.then((data) => cmReplayMultiple({
                data,
                handle,
                playback,
                start,
                views,
            }));
        }
        else {
            cmReplayMultiple({
                data: props.replay,
                handle,
                playback,
                start,
                views,
            });
        }
    }, []);
    return null;
}
