import { jsx as _jsx } from "react/jsx-runtime";
import { clamp } from "@liqvid/utils/misc";
import { onDrag } from "@liqvid/utils/react";
import { useMemo, useRef } from "react";
/**
 * Component for adjusting the vertical editor/console split.
 */
export function Resize({ dir = "ew", max = 0.75, min = 0.25, }) {
    const ref = useRef();
    /* event handlers */
    const resizeEvents = useMemo(() => {
        let container;
        return onDrag((e, { x, y }) => {
            const rect = container.getBoundingClientRect();
            if (dir === "ew") {
                container.style.setProperty("--split", clamp(min, (x - rect.left) / rect.width, max) * 100 + "%");
            }
            else if (dir === "ns") {
                container.style.setProperty("--v-split", clamp(min, (rect.bottom - y) / rect.height, max) * 100 + "%");
            }
        }, () => {
            container = ref.current.closest(".lqv-codebooth");
            container.classList.add("dragging");
        }, () => {
            container.classList.remove("dragging");
        });
    }, []);
    return (_jsx("div", { ...resizeEvents, ref: ref, className: `ui-resizable-handle ui-resizable-${dir}` }));
}
