import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { keymap } from "@codemirror/view";
import { PlaybackContext, useME } from "@lqv/playback/react";
import { useEffect, useRef } from "react";
import { useStore } from "zustand";
import { shortcuts } from "./extensions.mjs";
import { BoothStore, makeStore, useBoothStore } from "./store.mjs";
// buttons
export * from "./components/buttons.mjs";
export { Console } from "./components/Console.mjs";
export { Editor } from "./components/Editor.mjs";
export { EditorGroup } from "./components/EditorGroup.mjs";
export { EditorPanel } from "./components/EditorPanel.mjs";
export { FileTabs } from "./components/FileTabs.mjs";
export { Record } from "./components/Record.mjs";
export { Replay, ReplayMultiple } from "./components/Replay.mjs";
export { Resize } from "./components/Resize.mjs";
export * from "./extensions.mjs";
export { useBoothStore } from "./store.mjs";
/**
 * Container for code editing/recording/replaying.
 */
export const CodeBooth = (props) => {
    const { children, recorder, ...attrs } = props;
    const store = useRef();
    if (!store.current) {
        store.current = makeStore({ recorder });
    }
    const classNames = useStore(store.current, (state) => state.classNames);
    /* render */
    return (_jsx("div", { className: classNames.join(" "), "data-affords": "click", ...attrs, children: _jsx(BoothStore.Provider, { value: store.current, children: _jsxs(PlaybackContext.Provider, { value: useME(), children: [_jsx(KeyboardShortcuts, {}), props.children] }) }) }));
};
function KeyboardShortcuts() {
    const store = useBoothStore();
    useEffect(() => {
        // this is somewhat wasteful but oh well
        function reconfigure() {
            const state = store.getState();
            for (const groupName in state.groups) {
                for (const { view } of state.groups[groupName].files) {
                    view.dispatch({
                        effects: shortcuts.reconfigure([keymap.of(Object.values(state.shortcuts))]),
                    });
                }
            }
        }
        const unsubs = [];
        // update with new shortcuts
        unsubs.push(store.subscribe((state) => state.shortcuts, reconfigure));
        // update with new editors
        unsubs.push(store.subscribe((state) => state.groups, reconfigure));
        return () => {
            for (const unsub of unsubs) {
                unsub();
            }
        };
    }, []);
    return null;
}
