/// <reference types="react" />
import { Text } from "@codemirror/state";
import { cmReplay } from "@lqv/codemirror";
import { Store } from "../store";
import { Editor } from "./Editor";
declare type CodeData = Parameters<typeof cmReplay>[0]["data"];
/**
 * Editor to replay recorded coding.
 */
export declare function Replay(props: React.ComponentProps<typeof Editor> & {
    /**
     * Callback to handle special commands.
     * @param useStore The CodeBooth store.
     * @param cmd The command to handle.
     * @param doc The CodeMirror document.
     */
    handle?: (useStore: Store, cmd: string, doc: Text) => void;
    /** Coding data to replay. */
    replay?: CodeData | Promise<CodeData>;
    /**
     * Time to start replaying.
     * @default 0
     */
    start?: number;
}): JSX.Element;
/**
 * Replay coding to multiple editors.
 */
export declare function ReplayMultiple(props: {
    /** Editor group to replay. */
    group?: string;
    /**
     * Callback to handle special commands.
     * @param store The CodeBooth store.
     * @param cmd The command to handle.
     * @param docs CodeMirror documents.
     */
    handle?: (store: Store, cmd: string, docs: Record<string, Text>) => void;
    /**
     * Coding data to replay.
     */
    replay: CodeData | Promise<CodeData>;
    /**
     * Time to start replaying.
     * @default 0
     */
    start?: number;
}): null;
export {};
